/**
 * General Initialization and scripts
 *
 * @author Vedmant <vedmant@gmail.com>
 * @package Mental WP
 * @link http://azelab.com
 */
function fixScroll(hash){
    setTimeout(function(){
        jQuery('.top-main-menu li.active').removeClass('active');
        jQuery('.top-main-menu a[href="#' + hash + '"]').parent().addClass('active');
    },1000);
}
(function ($) {
	"use strict";

	// ============================================================================
	// Document Ready
	// ============================================================================

	$(document).ready(function () {

		if (urlParams['960px'] != undefined) $('body').addClass('cont-960');

		$('#menu-bar').mental_menu_bar();

		$('#mb-main-menu').mental_menu();

		$('.widget_nav_menu ul.menu').mental_menu(); // Widget Menu

		//  Start pie charts
		$(".knob").knob({
			draw: function () {
				// Add percents to value
				if (this.$.data('percents') == true) {
					$(this.i).val(this.cv + '%')
				}
			}
		});
		$(".knob").css({'font-size': '26px', 'color': '#444649'});

		// Init page animation if not on touch device
		animate_init();

		// Init Parallax - stellar.js
		$.stellar({
			responsive: true,
			horizontalScrolling: false,
			positionProperty: 'transform'
		});

		// Menu bar scrollbar
		$('.mb-body').css({position: 'relative', overflow: 'hidden'}).perfectScrollbar({
			wheelSpeed: 20,
			wheelPropagation: false,
			suppressScrollX: true
		});


		$('ul.gallery').mental_gallery();
		init_gallery_filters_underline();

		$('.isotope-blog').mental_blog();

		// Layerslider
		if ($.fn.layerSlider) {
			init_layer_slider();
		}

		// Menu
		if ($.fn.mtmenu) {
			wpml_lang_switcher_mtmenu_fix();
			$().mtmenu();
			init_smooth_scrolling();
			init_onepage_top_section();
			init_fixed_topbar();
		}

		// Set Full Height Sections
		$('.st-full-height').each(function(){
			if( ! $(this).closest('.onepage-top-section').length) $(this).height(window.innerHeight - $('#wpadminbar').height());
		});

		// Full height fix
		function resizeFullHeight() {
			$('.container-fullheight').height(window.innerHeight - $('#wpadminbar').height());
		}

		$(window).resize(function () {
			resizeFullHeight();
		});
		$(window).load(function () {
			resizeFullHeight();
		});
		setTimeout(function () {
			resizeFullHeight();
            init_gallery_filters_underline();
		}, 1);

		init_video_background();

		init_creative_mind();

		// Init Validation Engine
		if ($.fn.validationEngine) {
			$(".validation-engine").validationEngine();
		}

		init_ajax_forms();

		if( ! Modernizr.placeholder && $.fn.placeholder) $('input, textarea').placeholder();

		// Bootstrap tooltips
		if($.fn.tooltip) $('a[data-toggle="tooltip"]').tooltip();

		init_scroll_to_top();

		set_parallax_footer_height();
		$(window).on('load resize', set_parallax_footer_height);

    }); // Document ready


	// ============================================================================
	// Startup animations
	// ============================================================================

	function animate_init() {

		// Add animate class where data-animate attribute is set
		var
			startTopOfWindow = $(window).scrollTop();

		$('[data-animate]').each(function () {
			if ( ($(this).offset().top + $(this).height() > startTopOfWindow )
			   && Modernizr.csstransitions
				&& $(window).width() >= 768
				&& ! Modernizr.touch )
			{
				$(this).addClass('animated');
			}else $(this).removeAttr('data-animate');
		});

		// Skip animation for mobile devices
		if($(window).width() < 768 && Modernizr.touch) return;

		// Remove style for progress bars on start
		$('.progress-bar.animate').each(function () {
			var $this = $(this);
			// Remove progress-bar class and return it on timeout to cancel transition animation
			$this.removeClass('progress-bar').css('width', '');
			setTimeout(function () {
				$this.addClass('progress-bar')
			}, 10);
		});

		// Animate on page start
		setTimeout(function () {
			animate_on_scroll()
		}, 50);

		// Anitame elements on scroll
		$(window).bind('scroll.vmanimate', function () {
			animate_on_scroll();
		});

		// Remove classes after animate is complete
		$('.animated').one('webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend', function () {
			$(this).removeClass('animated').removeClass($(this).data('animate')).removeAttr('data-animate');
		});

		function animate_on_scroll() {
			var topOfWindow = $(window).scrollTop();
			var bottomOfWindow = topOfWindow + $(window).height();
			var $elms = $('.animated, .animate').each(function () {
				var $this = $(this);
				if ($this.offset().top + 100 < bottomOfWindow) {
					if ($this.hasClass('knob'))
						animate_knob($this);
					else if ($this.hasClass('progress-bar'))
						animate_progress($this);
					else if ($this.hasClass('animate-number'))
						animate_number($this);
					else
						$this.addClass($this.data('animate')).removeAttr('data-animate');
				}
			});
			if ($elms.length == 0) $(window).unbind('scroll.vmanimate');
		}

		function animate_knob($knob) {
			// Animate once
			$knob.removeClass('animate');
			var myVal = parseInt($knob.val());

			$({value: 0}).animate({value: myVal}, {
				duration: 1500,
				easing: 'swing',
				step: function () {
					$knob.val(Math.ceil(this.value)).trigger('change');
				}
			});
		}

		function animate_progress($progress) {
			// Animate once
			$progress.removeClass('animate');

			var valStart = parseInt($progress.attr('aria-valuemin'));
			var myVal = parseInt($progress.attr('aria-valuenow'));
			var $value = $progress.parent().siblings('.value');

			// Transitions animation
			$progress.css({width: myVal + '%'});

			$({value: valStart}).animate({value: myVal}, {
				duration: 1500,
				easing: 'swing',
				step: function () {
					$value.text(this.value.toFixed() + '%');
				}
			})
		}

		function animate_number($block) {
			// Animate once
			$block.removeClass('animate');

			var valStart = 0;
			var myVal = parseInt($block.text().replace(' ', ''));

			$({value: valStart}).animate({value: myVal}, {
				duration: 1500,
				easing: 'swing',
				step: function () {
					$block.text(this.value.toFixed().replace(/\B(?=(\d{3})+(?!\d))/g, " "));
				}
			})
		}

	} // animate_init


	// ============================================================================
	// Layer Slider
	// ============================================================================

	function init_layer_slider() {

		// Onepage 100% height
		var $ls_fullheiht = $('.ls-fullheight');
		var $ls_fullheiht_menu = $('.ls-fullheight-menu');
		var wpadminbar_height = $('#wpadminbar').height();
		var topmenu_height = $('.top-menu').height();
		if($ls_fullheiht.length || $ls_fullheiht.length){
			$ls_fullheiht.height(window.innerHeight - wpadminbar_height);
			$ls_fullheiht_menu.height(window.innerHeight - topmenu_height - wpadminbar_height);
		}

		// Layer (slide) to start from
		var firstLayer = 1;

		// Detect first layer if "gallery_single_full_show_around" option is used
		var $slider = $('#layerslider-singlework2, #layerslider-singlework1, #layerslider-singlework-thumbs');
		if( $slider.length ) {
			var $current_post_slide = $slider.find('.current-post-slide');
			if( $current_post_slide.length) firstLayer = $current_post_slide.index() + 1;
		}

		// Usual slider
		$('#layerslider').layerSlider({
			sublayerContainer: 1170,
			skin: 'mental',
			skinsPath: mental_vars.siteurl+'/wp-content/themes/mental/assets/plugins/layerslider/skins/',
			showBarTimer: true,
			showCircleTimer: false,
			pauseOnHover: false,
			firstLayer: firstLayer
		});

		// Single Work style 1
		$('#layerslider-singlework1').layerSlider({
			skin: 'mental',
			skinsPath: mental_vars.siteurl+'/wp-content/themes/mental/assets/plugins/layerslider/skins/',
			showBarTimer: true,
			showCircleTimer: false,
			pauseOnHover: false,
			autoStart: false,
			firstLayer: firstLayer,
			cbAnimStart: function (data) {
				$('#lsmb-title').text(data.nextLayer.data('title'));
			}
		});

		// Single Work style 2
		$('#layerslider-singlework2').layerSlider({
			// sublayerContainer: 1170,
			skin: 'mental',
			skinsPath: mental_vars.siteurl+'/wp-content/themes/mental/assets/plugins/layerslider/skins/',
			showBarTimer: true,
			showCircleTimer: false,
			pauseOnHover: false,
			autoStart: false,
			firstLayer: firstLayer,
			cbAnimStart: function (data) {
				$('.ls-mn-counter').html('<em>' + pad(data.nextLayerIndex, 2) + '</em>/' + pad(data.layersNum, 2));
			}
		});
		$('.ls-mn-prev').click(function (e) {
			e.preventDefault();
			$('#layerslider-singlework2').layerSlider('prev');
		});
		$('.ls-mn-next').click(function (e) {
			e.preventDefault();
			$('#layerslider-singlework2').layerSlider('next');
		});

		function pad(str, max) {
			str = str.toString();
			return str.length < max ? pad("0" + str, max) : str;
		}

		// Single Work with thumbnails
		$('#layerslider-singlework-thumbs').layerSlider({
			skin: 'mental',
			skinsPath: mental_vars.siteurl+'/wp-content/themes/mental/assets/plugins/layerslider/skins/',
			responsive: true,
			showBarTimer: true,
			showCircleTimer: false,
			pauseOnHover: false,
			autoStart: false,
			thumbnailNavigation: 'always',
			tnWidth: 170,
			tnHeight: 110,
			tnActiveOpacity: 100,
			tnInactiveOpacity: 40,
			tnContainerWidth: '80%',
			firstLayer: firstLayer,
			cbAnimStart: function (data) {
				$('#lsmb-title').text(data.nextLayer.data('title'));
			}
		});


		// Onepage - Scroll under slider on click on round white arrow
		$('.ls-mental-scrollunder').click(function (e) {
			e.preventDefault();
			$('html, body').animate({
				scrollTop: $('#layerslider').outerHeight(true) + 40
			}, 1000);
		});

	}


	// ============================================================================
	// Smooth scrolling to element ID
	// ============================================================================

	function init_smooth_scrolling() {
		var fixed_topbar_height = $('body').data('offset') - 5;
		$(".smoothscroll a[href^='#']").on('click', function (e) {
                        var hashTag = $.attr(this, 'href').substr(1);
			if ($(this).closest(".nav-tabs").length) return true;
			// prevent default anchor click behavior
			e.preventDefault();
			// add hash to url

			if ($(this.hash).offset()) var top = $(this.hash).offset().top;
			else var top = 0;
                        
                        $('html, body').stop();
			$('html, body').animate({
				scrollTop: top - fixed_topbar_height
			}, 1000, function(){
                                window.location.hash = hashTag;
                                $('html, body').scrollTop(top - fixed_topbar_height);
				if(typeof(window.history.pushState) == 'function') {
					//window.history.pushState(null, null, this.hash);
				} else {
					//window.location.hash = this.hash;
					$('html, body').scrollTop(top - fixed_topbar_height);
				}
			});

		});
	}

	window.addEventListener("popstate", function (e) {
		if (location.hash && jQuery(".smoothscroll a[href='" + location.hash + "']").length) {
			//jQuery(".smoothscroll a[href='" + location.hash + "']").trigger('click');
		}
	});


	// ============================================================================
	// Fixed top Menu Bar
	// ============================================================================

	function init_fixed_topbar() {
		var offset = 0;
		var $top_menu = $('.top-menu.tm-fixonscroll');
		var prevTop = 0;
		if (!$top_menu.length) return;
		if ($top_menu.data('fixed-on-scroll-top') == '1') {
			$(window).scroll(function () {
				if (($(window).scrollTop() > $('.top-menu.tm-fixonscroll').offset().top + offset)) {
					if ($(window).scrollTop() < prevTop) {
						$top_menu.addClass('tm-fixed').removeClass('tm-fixed-hidden');
					} else if ($(window).scrollTop() > prevTop) {
						$top_menu.removeClass('tm-fixed').addClass('tm-fixed-hidden');
					}
				} else {
					$top_menu.removeClass('tm-fixed');
				}
				prevTop = $(window).scrollTop();
			});
		} else {
			$(window).scroll(function () {
				if (($(window).scrollTop() > $('.top-menu.tm-fixonscroll').offset().top + offset)) {
					$top_menu.addClass('tm-fixed');
				} else {
					$top_menu.removeClass('tm-fixed');
				}
			});
		}
	}


	// ============================================================================
	// Gallery filters moving on hover underline
	// ============================================================================

	function init_gallery_filters_underline() {

		$('.gallery-filters > li > a.active').each(function () {
			go_to_item($(this).parent());
		});

		$('.gallery-filters >li:not(.gf-underline)').hover(function () {
			go_to_item($(this));
		}, function () {
			go_to_item($(this).parent().find('li > a.active').parent());
		});

		function go_to_item($item) {
			if ($item.length == 0) return;
			var parent_left = $item.parent().length ? $item.parent().offset().left : 0;
			var offset = $item.offset().left - parent_left;
			$item.siblings('.gf-underline').css({left: offset, width: $item.width()});
		}
	}


	// ============================================================================
	// Video background
	// ============================================================================

	function init_video_background() {

		var $video_container = $('.st-video-background');
		var $video = $video_container.find('video');

		var vid_w_orig = parseInt($video.attr('width'));
		var vid_h_orig = parseInt($video.attr('height'));

		$(window).resize(function () {
			resizeToCover();
		});
		resizeToCover();

		function resizeToCover() {
			// use largest scale factor of horizontal/vertical
			var scale_h = $video_container.width() / vid_w_orig;
			var scale_v = $video_container.height() / vid_h_orig;
			var scale = scale_h > scale_v ? scale_h : scale_v;
			// scale the video
			$video.width(scale * vid_w_orig);
			$video.height(scale * vid_h_orig);
			// center it by scrolling the video viewport
			$video_container.scrollLeft(($video.width() - $(window).width()) / 2);
			$video_container.scrollTop(($video.height() - $(window).height()) / 2);
		}

		// Firefox fix: play in loop
		$video.bind('ended', function () {
			this.play();
		});
	}


	// ============================================================================
	// Creative Mind Block
	// ============================================================================

	function init_creative_mind() {
		$('.cm-item').hover(function () {
			var $this = $(this);
			var $creative_minds = $this.closest('.creative-minds');
			$creative_minds.find('.col-cm').removeClass('active');
			$this.closest('.col-cm').addClass('active');
		});
	}


	// ============================================================================
	// Send form using Ajax
	// ============================================================================

	function init_ajax_forms() {
		$('.ajax-send').submit(function (e) {
			e.preventDefault();
			var $this = $(this);
			var action = $this.attr('action');

			if (!$this.validationEngine('validate')) return false;

			var $spinner = $this.find('.loading-spinner').show();

			$.ajax({
				type: "POST",
				url: 'formmail.php',
				data: $this.serialize(), // serializes the form's elements.
				success: function (data) {
					$this.find('input[type=text], input[type=email], textarea').val(''); // Clear form
					$this.prepend('<div class="alert alert-success">Your message was sent!</div>'); // Show success message
				},
				complete: function (jqXHR, textStatus) {
					$spinner.hide();
				},
				error: function (jqXHR, textStatus, errorMessage) {
					console.log(errorMessage);
				}
			});

		});
	}

	// ============================================================================
	// Onepage Top Section
	// ============================================================================

	function init_onepage_top_section() {
		$('.onepage-top-section.ots-full').height(window.innerHeight - $('#wpadminbar').height());
		$('.onepage-top-section.ots-full-menu').height(window.innerHeight - $('#wpadminbar').height() - $('.top-menu').height());
	}


	// ============================================================================
	// WPML language switcher in mtmenu fix
	// ============================================================================

	function wpml_lang_switcher_mtmenu_fix()
	{
		$(".mtmenu .submenu-languages").addClass('dropdown');
	}


	// ============================================================================
	// Scroll to top
	// ============================================================================

	function init_scroll_to_top()
	{
		if($('#azl_scroll_up').length == 0) return;

		function pos(){
			if($(window).scrollTop() != 0) {
				$('#azl_scroll_up').css('transform', 'translateX(-20px) translateZ(0)');
			} else {
				$('#azl_scroll_up').css('transform', 'translateX(100%) translateZ(0)');
			}
		}

		$(window).scroll(pos);

		$('#azl_scroll_up').on('click touchstart', function(e) {
			e.preventDefault();
			$('body,html').animate({scrollTop:0},800);
		});
	}

	function set_parallax_footer_height()
	{
		if($( ".parallax-footer" ).length > 0 && $('.footer').length > 0) {
			var margin_bottom = ($(window).width() > 1199) ? $('.footer').outerHeight(true) : 0;
			//var margin_bottom = $('.footer').outerHeight(true);
			if($('#main').length > 0)
				$('#main').css('margin-bottom', margin_bottom);
		}
	}


	// ============================================================================
	// Open cart
	// ============================================================================

	var stop_ajax = 1, is_add = '';
	$(document).on('click', '.ajax_add_to_cart', function () {
		stop_ajax = 2;
		is_add = 'added';
	});

	$(document).on('click', '.product-remove .remove', function () {
		stop_ajax = 3;
		is_add = 'remove';
	});

	$(document).ajaxComplete(function () {
		if (stop_ajax == 2 && is_add == 'added') {
			changeCart();
			stop_ajax = 1, is_add = '';
		}

		if (stop_ajax == 3 && is_add == 'remove') {
			RemoveCartProduct();
			stop_ajax = 1, is_add = '';
		}
	});

	function changeCart() {

		$.ajax({
			type: 'POST',
			url: ajaxurl,
			data: {
				action: 'ms_poput_cart_product'
			},
			dataType: 'json',

			complete: function (response) {
				var json = response.responseJSON;
				$('.nm-menu-cart-count.count').text(json.cart_count);

			}
		});
	}

	function RemoveCartProduct() {

		$.ajax({
			type: 'POST',
			url: ajaxurl,
			data: {
				action: 'ms_mini_cart_remove_product',
			},
			dataType: 'json',

			complete: function (response) {
				var json = response.responseJSON;
				$('.nm-menu-cart-count.count').text(json.cart_count);
			}
		});
	}

})(jQuery);
