<?php defined( 'ABSPATH' ) OR exit( 'restricted access' ); // Protect against direct call

/**
 * Filter attributes and set defaults
 *
 * @param $atts
 *
 * @return array
 */
function vcm_mental_gallery_atts( $atts ) {
	return shortcode_atts( array(
		'id'                    => 'gallery-' . rand( 1, 999 ),
		'category'              => '',
		'type'                  => get_mental_option( 'gallery_type' ),
		'items_per_page'        => get_mental_option( 'gallery_items_per_page' ),
		'columns_count'         => get_mental_option( 'gallery_columns_count' ),
		'columns_count_sm'      => '1',
		'show_load_more'        => 'yes',
		'show_filter'           => 'yes',
		'filter_align'          => 'left',
		'show_all_filter'       => 'yes',
		'initial_filter'        => '',
		'fixed_items'           => get_mental_option( 'gallery_fixed_items' ),
		'load_on_scroll'        => 'no',
		'preview_full_size'     => get_mental_option( 'gallery_preview_full_size' ) ? 'yes' : 'no',
		'preview_show_zoom'     => get_mental_option( 'gallery_preview_show_zoom' ) ? 'yes' : 'no',
		'preview_show_readmore' => get_mental_option( 'gallery_preview_show_readmore' ) ? 'yes' : 'no',
		'preview_show_share'    => get_mental_option( 'gallery_preview_show_share' ) ? 'yes' : 'no',
		'ajax_action'           => 'mental_gallery',
		'item_padding'          => '0',
		'orderby'               => 'date',
		'order'                 => 'DESC',
		'slider_auto_play'      => get_mental_option( 'gallery_preview_slider_auto_play' ),
		'url_hash'              => get_mental_option( 'gallery_url_hash', 'yes' ),
		'enable_ajax'           => get_mental_option( 'gallery_enable_ajax', 'no'),
	), $atts, 'vcm_mental_gallery' );
}
/**
 * "vcm_mental_gallery" shortcode entry function
 *
 * @param $atts
 * @param null $content
 *
 * @return string
 */
function vcm_mental_gallery_shortcode( $atts, $content = null ) {
	$atts = vcm_mental_gallery_atts( $atts );

	$filters = vcm_mental_gallery_filters( $atts );

	// Set default initial filter to first one if "All" filter was disabled
	if ( $atts['show_all_filter'] === 'no' && $atts['initial_filter'] === '' && $filters) {
		$atts['initial_filter'] = $filters[0]->slug;
	}

	ob_start();
	?>

	<ul class="gallery-filters" data-gallery-id="<?php echo esc_attr( $atts['id'] ); ?>"
	    style="text-align: <?php echo esc_attr( $atts['filter_align'] ); ?>;
	           <?php if ( empty( $filters ) || $atts['show_filter'] == 'no') echo 'display: none;' ?>">
		<?php if ( $atts['show_all_filter'] === 'yes' ): ?>
			<li><a class="<?php if ( $atts['initial_filter'] === '' ) echo 'active'; ?>" data-filter="*" href="#"><?php _e( 'All', 'mental' ) ?></a></li>
		<?php endif; ?>
		<?php foreach ( $filters as $i => $filter ): ?>
			<li>
				<a data-filter="<?php echo esc_attr($filter->slug) ?>" href="#"
				   class="<?php if ( $atts['initial_filter'] === $filter->slug ) echo 'active'; ?>">
					<?php echo esc_html($filter->name); ?>
				</a>
			</li>
		<?php endforeach ?>
		<li class="gf-underline"></li>
	</ul>

	<ul id="<?php echo esc_attr($atts['id']); ?>"
	    class="gallery gl-cols-<?php echo esc_attr($atts['columns_count']); ?> <?php echo ( $atts['type'] == 'pinterest' ) ? 'gl-pinterest' : '' ?>"
	    data-options="<?php echo esc_attr(azl_serialize_atts($atts)); ?>">

		<?php vcm_mental_gallery_loop( 0, $atts ) ?>
	</ul> <!-- gallery -->

	<?php if ( $atts['load_on_scroll'] == 'yes' ): ?>
		<div class="load-more-block dark lmb-on-scroll">
			<span class="loading-spinner"></span>
			<span class="no-more-items-sign"><?php _e( 'No more items', 'mental' ) ?></span>
		</div>
	<?php endif ?>

	<?php if ( $atts['show_load_more'] == 'yes' && $atts['load_on_scroll'] == 'no' ): ?>
		<div class="load-more-block dark">
			<a href="#" class="load-more-button" data-gallery-id="<?php echo esc_attr( $atts['id'] ); ?>"><?php _e( 'Load more', 'mental' ) ?></a>
			<span class="loading-spinner"></span>
			<span class="no-more-items-sign"><?php _e( 'No more items', 'mental' ) ?></span>
		</div>
	<?php endif ?>

	<?php
	return ob_get_clean();
}

/**
 * Gallery items loop
 *
 * @param $offset
 * @param $atts
 * @param $ajax
 */
function vcm_mental_gallery_loop( $offset, $atts, $ajax = false ) {
	$atts = vcm_mental_gallery_atts( $atts );

	/*
	 * The query
	 */

	$paged = ceil( $offset / $atts['items_per_page'] ) + 1;

	// Can work with or ID or Slug
	if ( intval( $atts['category'] ) ) {
		$tax_field = 'term_id';
	} else {
		$tax_field = 'slug';
	}

	$tax_query = array();

	if ( ! empty( $atts['category'] ) ) {
		$tax_query[] = array(
			'taxonomy' => 'gallery_category',
			'terms'    => $atts['category'],
			'field'    => $tax_field,
		);
	}

	// Load posts only with filters if "All" filter is disabled
	if ( $atts['show_all_filter'] === 'no') {
		$filters = vcm_mental_gallery_filters( $atts );
		if ($filters) {
			$filters = array_map(function ($item) { return $item->term_id; }, $filters);
			$tax_query[] = array(
				'taxonomy' => 'gallery_filter',
				'terms'    => $filters,
				'field'    => 'term_id',
				'operator' => 'IN',
			);
		}
	}

	query_posts( array(
		'post_type'      => 'gallery',
		'tax_query'      => $tax_query,
		'post_status'    => 'publish',
		'posts_per_page' => $atts['enable_ajax'] === 'yes' ? $atts['items_per_page'] : -1,
		'paged'          => $paged,
		'orderby'        => $atts['orderby'],
		'order'          => $atts['order']
	) );

	/*
	 * The loop
	 */

	$i = 0;
	while ( have_posts() ) : the_post();

		// Get item categories (filters)
		$post_filters = wp_get_post_terms( get_the_ID(), 'gallery_filter' );
		$filt_names   = array();
		$filt_slugs   = array();

		foreach ( $post_filters as $post_filter ) {
			$filt_names[] = $post_filter->name;
			$filt_slugs[] = $post_filter->slug;
		}

		$meta = get_post_meta( get_the_ID(), 'gallery_item', true );

		/*
		 * Item classes
		 */

		$classes = array( 'gl-item gallery-item', 'gl-loading' );

		// Double size item
		if ( ! empty( $meta['double_size'] ) && $atts['type'] != 'expanding' ) {
			$classes[] = 'gl-double';
		}

		// Fixed ratio item
		if ( ( $atts['fixed_items'] == 'fixed' || $atts['type'] == 'expanding' ) && 'pinterest' != $atts['type'] ) {
			$classes[] = 'gl-fixed-ratio-item';
		}

		// Hide items if more that should be on the page or current item not in initial filter
		if ( ! $ajax && ($i >= $atts['items_per_page'] || ( $atts['initial_filter'] && ! in_array( $atts['initial_filter'], $filt_slugs ) ) ) ) {
			$classes[] = 'gl-hidden';
		}

		/*
		 * Render item
		 */

		?>
		<li class="<?php echo implode(' ', $classes); ?>"
		    data-post-id="<?php echo esc_attr(get_the_ID()); ?>"
		    data-category="<?php echo implode( ', ', $filt_slugs ) ?>"
		    style="padding: <?php echo esc_attr( $atts['item_padding'] ) . 'px'; ?>">

			<a href="<?php the_permalink() ?>">
				<figure>
					<?php if ( has_post_thumbnail() ): ?>
						<?php
						if ( class_exists( 'MultiPostThumbnails' ) && MultiPostThumbnails::has_post_thumbnail( get_post_type(), 'additional_thumbnail' ) ) :
							MultiPostThumbnails::the_post_thumbnail( get_post_type(), 'additional_thumbnail' );
						else:
							the_post_thumbnail( 'medium', array( 'alt' => '' ) );
						endif;
						?>
					<?php else: ?>
						<?php
						$placeholder_image = get_mental_option( 'gallery_placeholder' ); // returns an array
						if ( $placeholder_image && $placeholder_image_src = wp_get_attachment_image_src( $placeholder_image, 'medium' ) ) { ?>
							<img src="<?php echo esc_url( $placeholder_image_src[0] ); ?>" alt="slide">
						<?php } else { ?>
							<img src="http://placehold.it/700x471" alt="slide">
						<?php } ?>
					<?php endif ?>
					<figcaption>
						<div class="middle">
							<div class="middle-inner">

								<?php if ( $atts['type'] != 'pinterest' ): ?>
									<?php if ( get_post_format() == 'gallery' ): ?>
										<p class="gl-item-icon"><i class="fa fa-picture-o"></i></p>
									<?php elseif ( get_post_format() == 'video' ): ?>
										<p class="gl-item-icon"><i class="fa fa-play-circle-o"></i></p>
										<?php
									elseif ( get_post_format() == 'audio' ): ?>
										<p class="gl-item-icon"><i class="fa fa-music"></i></p>
									<?php endif ?>
								<?php endif ?>

								<p class="gl-item-title"><?php the_title(); ?></p>

								<?php if ( $atts['type'] == 'pinterest' ): ?>
									<p class="gl-item-descr"><?php the_mental_excerpt( 'mental_excerpt_length_20' ); ?></p>
								<?php else: ?>
									<p class="gl-item-category"><?php echo implode( ', ', $filt_names ) ?></p>
								<?php endif ?>

							</div>
						</div>
					</figcaption>
				</figure>
			</a>

			<?php if ( $atts['type'] == 'expanding' ): ?>

				<div class="gl-preview" style="display: none;">
					<span class="glp-arrow"></span>
					<a href="#" class="glp-close"></a>

					<?php if ( $atts['preview_full_size'] == 'yes' ): ?>

						<div class="glp-fullsize">
							<?php vcm_mental_gallery_preview( $atts, 'full' ); ?>
						</div>

					<?php else: ?>

						<div class="row gl-preview-container">

							<div class="col-sm-8 gl-preview-image">
								<?php vcm_mental_gallery_preview( $atts ); ?>
							</div>

							<div class="col-sm-4 lg-preview-descr">

								<h4><?php the_title(); ?></h4>

								<?php if ( get_post_format() == 'audio' ): ?>
									<?php the_mental_audio_excerpt( 'wp-audio-shortcode-preview' ); ?>
									<?php the_mental_playlist_excerpt( 'wp-playlist-preview' ); ?>
									<?php
									    $my_excerpt = get_the_excerpt();
									     if($my_excerpt !='') {
									         the_excerpt();
									     }
									?>
								<?php else: ?>
									<?php the_excerpt(); ?>
								<?php endif ?>

								<?php if ( $atts['preview_show_readmore'] == 'yes' ): ?>
									<a href="<?php the_permalink() ?>"
									   class="btn btn-primary glp-readmore"><?php _e( 'Read More', 'mental' ) ?></a>
								<?php endif ?>

								<?php if ( $atts['preview_show_share'] == 'yes' && get_mental_option( 'social_block_show' ) ): ?>
									<div class="mb-social glp-social">
										<?php get_template_part( 'blocks/social-share' ) ?>
									</div>
								<?php endif ?>

							</div>

						</div>

					<?php endif ?>

				</div> <!-- gl-preview -->

			<?php endif ?>

		</li>

	<?php
	$i++;
	endwhile;
	wp_reset_query();
	?>
	<?php
}

/**
 * Gallery item preview
 *
 * @param $atts
 * @param string $preview_size
 */
function vcm_mental_gallery_preview( $atts, $preview_size = 'medium' ) {
	?>

	<?php if ( get_post_format() == 'video' && $video = get_post_video( get_the_content(), 'wp-video-shortcode-preview' ) ): ?>

		<div class="responsive-embed">
			<?php echo mental_escape_iframe( $video ); ?>
		</div>

	<?php elseif ( get_post_format() == 'gallery' && $gallery = get_post_gallery( get_the_ID(), false ) ) : // If Post gallery {?>

		<div id="carousel-<?php echo get_the_ID() ?>" class="carousel slide" data-ride="carousel" data-interval="<?php echo $atts['slider_auto_play'] ? '5000' : 'false'; ?>">

			<!-- Wrapper for slides -->
			<div class="carousel-inner">
				<?php
				$img_ids = explode( ',', $gallery['ids'] );
				$i       = 0;
				foreach ( $img_ids as $img_id ):
					?>
					<?php $img_src = wp_get_attachment_image_src( $img_id, $preview_size ) ?>
					<?php $img_full_src = wp_get_attachment_image_src( $img_id, 'full' ) ?>
					<div class="item <?php echo ( $i == 0 ) ? 'active' : '' ?>">
						<img src="<?php echo esc_url( $img_src[0] ); ?>" alt="slide">
						<?php if ( $atts['preview_show_zoom'] == 'yes' ): ?>
							<a class="glp-zoom" data-image="<?php echo esc_url( $img_full_src[0] ); ?>"><i></i></a>
						<?php endif ?>
					</div>
					<?php $i ++; endforeach ?>
			</div>
			<!-- Indicators -->
			<ol class="carousel-indicators">
				<?php $i = 0;
				foreach ( $img_ids as $img_id ): ?>
					<li data-target="#carousel-<?php echo get_the_ID() ?>" data-slide-to="<?php echo (int) $i ?>"
					    class="<?php echo ( $i == 0 ) ? 'active' : '' ?>"></li>
					<?php $i ++; endforeach ?>
			</ol>

			<!-- Controls -->
			<a class="left carousel-control" href="#carousel-<?php echo get_the_ID() ?>" data-slide="prev">
				<span></span>
			</a>
			<a class="right carousel-control" href="#carousel-<?php echo get_the_ID() ?>" data-slide="next">
				<span></span>
			</a>

		</div> <!-- carousel -->

	<?php elseif ( has_post_thumbnail() ):
		$img_full_src = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );
		?>
		<figure>
			<?php the_post_thumbnail( $preview_size ) ?>
			<?php if ( $atts['preview_show_zoom'] == 'yes' ): ?>
				<a class="glp-zoom" data-image="<?php echo esc_url( $img_full_src[0] ); ?>"><i></i></a>
			<?php endif ?>
		</figure>
	<?php else: ?>
		<figure>
			<?php _e( 'No featured image selected', 'mental' ) ?>
		</figure>
	<?php endif ?>

	<?php
}

/**
 * Get gallery categories list
 *
 * @return array
 */
function vcm_mental_gallery_categories() {
	$gallery_categories_raw = get_terms( 'gallery_category', 'orderby=name&hide_empty=0' );
	$gallery_categories     = array( __( 'All', 'mental' ) => '' );
	if(taxonomy_exists('$gallery_categories')){
	foreach ( $gallery_categories_raw as $gallery_category ) {
		$gallery_categories[ $gallery_category->name ] = $gallery_category->term_id;
	}
	}
	return $gallery_categories;
}

/**
 * Get gallery filters
 *
 * @param array $atts
 *
 * @return array|int|mixed|WP_Error
 */
function vcm_mental_gallery_filters( $atts = null ) {
	if ( null !== $atts && ! empty( $atts['category'] ) ) {
		$filters = azl_get_category_tags( $atts['category'], 'gallery_filter', 'gallery_category' );
	} else {
		$filters = get_terms( 'gallery_filter', array( 'orderby' => 'name', 'hide_empty' => 1 ) );
	}

	return $filters;
}

/**
 * Get filters list formatted for options
 *
 * @return array
 */
function vcm_mental_gallery_filters_options() {
	$filters_raw = vcm_mental_gallery_filters();
	$filters     = array( __( 'All', 'mental' ) => '' );
if(taxonomy_exists('$filters')){
	foreach ( $filters_raw as $filter ) {
		$filters[ $filter->name ] = $filter->slug;
	}
}
	return $filters;
}

/*
 * Add Visual Composer settings
 */
add_filter( 'vc_before_init', 'register_vcm_mental_custom_gallery' );
function register_vcm_mental_custom_gallery() {
	vc_map( array(
		'icon'            => 'vcm-mental-gallery',
		'name'            => __( 'Mentas Gallery', 'mental' ),
		"base"            => "vcm_mental_gallery", // bind with our shortcode
		"content_element" => true, // set this parameter when element will has a content
		//"is_container" => true, // set this param when you need to add a content element in this element
		"category"        => __( 'Mentas Elements', 'mental' ),
		// Here starts the definition of array with parameters of our compnent
		"params"          => array(
			array(
				'type'       => 'dropdown',
				'param_name' => 'category',
				'heading'    => __( 'Gallery category', 'mental' ),
				'value'      => vcm_mental_gallery_categories()
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'type',
				'heading'    => __( 'Gallery type', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					'Expanding' => 'expanding',
					'Normal'    => 'normal',
					'Pinterest' => 'pinterest',
				),
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'load_on_scroll',
				'heading'    => __( 'Load new items on scroll (infinite scroll)', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					__( 'No', 'mental' )  => 'no',
					__( 'Yes', 'mental' ) => 'yes',
				)
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'show_filter',
				'heading'    => __( 'Show filters panel', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					__( 'Yes', 'mental' ) => 'yes',
					__( 'No', 'mental' )  => 'no',
				)
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'filter_align',
				'heading'    => __( 'Filter align', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					'Left'   => 'left',
					'Center' => 'center',
					'Right'  => 'right',
				)
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'show_all_filter',
				'heading'    => __( 'Show "All" filter', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					__( 'Yes', 'mental' ) => 'yes',
					__( 'No', 'mental' )  => 'no',
				)
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'initial_filter',
				'heading'    => __( 'Initial filter', 'mental' ),
				'value'      => vcm_mental_gallery_filters_options(),
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'show_load_more',
				'heading'    => __( 'Show load more', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					__( 'Yes', 'mental' ) => 'yes',
					__( 'No', 'mental' )  => 'no',
				)
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'fixed_items',
				'heading'    => __( 'Fixed images ratio', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					__( 'No', 'mental' )  => 'no',
					__( 'Yes', 'mental' ) => 'yes',
				)
			),
			array(
				'type'       => 'textfield',
				'param_name' => 'items_per_page',
				'heading'    => __( 'Items per page', 'mental' )
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'columns_count',
				'heading'    => __( 'Columns count', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					'3' => '3',
					'4' => '4',
					'5' => '5'
				)
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'columns_count_sm',
				'heading'    => __( 'Columns count on small device', 'mental' ),
				'value'      => array( 1, 2 )
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'preview_full_size',
				'heading'    => __( 'Show full size preview', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					__( 'No', 'mental' )  => 'no',
					__( 'Yes', 'mental' ) => 'yes',
				)
			),
			array(
				'type'       => 'textfield',
				'param_name' => 'item_padding',
				'heading'    => __( 'Item padding', 'mental' ),
				'value'      => '0'
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'orderby',
				'heading'    => __( 'Sort retrieved posts by parameter. Defaults to \'date (post_date)\'.', 'mental' ),
				'value'      => array(
					'No order'                       => 'none',
					'Order by post id'               => 'ID',
					'Order by author'                => 'author',
					'Order by title'                 => 'title',
					'Order by post name (post slug)' => 'name',
					'Order by date'                  => 'date',
					'Order by last modified date'    => 'modified',
					'Random order'                   => 'rand',
					'Order by number of comments'    => 'comment_count',
				)
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'order',
				'heading'    => __( 'Designates the ascending or descending order of the \'orderby\' parameter.', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					'ASC'  => 'ASC',
					'DESC' => 'DESC',
				)
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'slider_auto_play',
				'heading'    => __( 'Auto play slider', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					__( 'No', 'mental' )      => '0',
					__( 'Yes', 'mental' )     => '1',
				)
			),
			array(
				'type'       => 'textfield',
				'param_name' => 'id',
				'heading'    => __( 'Gallery ID', 'mental' )
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'url_hash',
				'heading'    => __( 'Enable filters URL hash', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					__( 'No', 'mental' )      => 'no',
					__( 'Yes', 'mental' )     => 'yes',
				),
				"description" => __( "When enabled you will see #filter:filter-name hash in URL string when clicking on filters. Link with #filter:filter-name will select specified filter on page load.", "mental" )
			),
			array(
				'type'       => 'dropdown',
				'param_name' => 'enable_ajax',
				'heading'    => __( 'Enable Ajax Loading', 'mental' ),
				'value'      => array(
					__( 'Default', 'mental' ) => '',
					__( 'No', 'mental' )      => 'no',
					__( 'Yes', 'mental' )     => 'yes',
				),
				"description" => __( "Enable this option if you have a lot of gallery posts and want to reduce initial page loading time. However, when this option is enabled galleries will not be loaded evenly for each filter.", "mental" )
			),
		)
	) );
}
