<?php
/**
 * Display single product reviews (comments)
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.5.0
 */
global $product;

if ( ! defined( 'ABSPATH' ) )
	exit; // Exit if accessed directly

if ( ! comments_open() )
	return;
?>
<div id="reviews">
	<div id="comments">
		<h4><?php
			if ( get_option( 'woocommerce_enable_review_rating' ) === 'yes' && ( $count = $product->get_rating_count() ) )
				printf( _n( '%s review for %s', '%s reviews for %s', $count, 'mental' ), $count, get_the_title() );
			else
				_e( 'Reviews', 'mental' );
		?></h4>

		<?php if ( have_comments() ) : ?>

			<ol class="commentlist">
				<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
			</ol>

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links( apply_filters( 'woocommerce_comment_pagination_args', array(
					'prev_text' => '&larr;',
					'next_text' => '&rarr;',
					'type'      => 'list',
				) ) );
				echo '</nav>';
			endif; ?>

		<?php else : ?>

			<p class="woocommerce-noreviews"><?php _e( 'There are no reviews yet.', 'mental' ); ?></p>

		<?php endif; ?>
	</div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>

		<div id="review_form_wrapper">
			<div id="review_form">
				<?php
					$commenter = wp_get_current_commenter();

					$comment_form = array(
						'title_reply'          => have_comments() ? __( 'Add a review', 'mental' ) : __( 'Be the first to review', 'mental' ) . ' &ldquo;' . get_the_title() . '&rdquo;',
						'title_reply_to'       => __( 'Leave a Reply to %s', 'mental' ),
						'comment_notes_before' => '',
						'comment_notes_after'  => '',
						'fields'               => array(
							'author' => '<p class="comment-form-author">' . '<label for="author">' . __( 'Name', 'mental' ) . ' <span class="required">*</span></label> ' .
							            '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" aria-required="true" /></p>',
							'email'  => '<p class="comment-form-email"><label for="email">' . __( 'Email', 'mental' ) . ' <span class="required">*</span></label> ' .
							            '<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" aria-required="true" /></p>',
						),
						'label_submit'  => __( 'Submit', 'mental' ),
						'logged_in_as'  => '',
						'comment_field' => ''
					);

					if ( get_option( 'woocommerce_enable_review_rating' ) === 'yes' ) {
						$comment_form['comment_field'] = '<div class="col-sm-12"><p class="comment-form-rating"><label for="rating">' . __( 'Your Rating', 'mental' ) .'</label><select name="rating" id="rating">
							<option value="">' . __( 'Rate&hellip;', 'mental' ) . '</option>
							<option value="5">' . __( 'Perfect', 'mental' ) . '</option>
							<option value="4">' . __( 'Good', 'mental' ) . '</option>
							<option value="3">' . __( 'Average', 'mental' ) . '</option>
							<option value="2">' . __( 'Not that bad', 'mental' ) . '</option>
							<option value="1">' . __( 'Very Poor', 'mental' ) . '</option>
						</select></p></div>';
					}

					$commenter = wp_get_current_commenter();
					$comment_form['fields']   =  array(
						'author' => '<div class="col-sm-4"><p class="comment-form-author">' .
						            '<input id="author" class="form-control" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" aria-required="true" placeholder="' . __( 'Name *', 'mental' ) .'" /></p></div>',
						'email'  => '<div class="col-sm-4"><p class="comment-form-email">' .
						            '<input id="email" class="form-control" name="email" type="email" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" aria-required="true" placeholder="'. __( 'Email *', 'mental' ) .'" /></p></div>',
						'url'    => '<div class="col-sm-4"><p class="comment-form-url">' .
						            '<input id="url" class="form-control" name="url" type="url" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" placeholder="'. __( 'Website', 'mental' ) .'" /></p></div>',
					);

					$comment_form['comment_field'] .= '<div class="col-sm-12"><p class="comment-form-comment"><textarea id="comment" class="form-control" name="comment" rows="6" aria-required="true" placeholder="'.__( 'Your Review *', 'mental' ).'"></textarea></p>';

				?>
				<div class="row">
					<?php comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) ); ?>
					</div> <!-- closing div, opened before comment textatea -->
				</div>
			</div>
		</div>

	<?php else : ?>

		<p class="woocommerce-verification-required"><?php _e( 'Only logged in customers who have purchased this product may leave a review.', 'mental' ); ?></p>

	<?php endif; ?>

	<div class="clear"></div>
</div>